module com.reinhardt.annotationdiscoveryvisitornpe {
    requires java.compiler;
}
